@@ -3,7 +3,6 @@
 from flask import Flask, request
 from external import configure
 
-
 # Flask constructor takes the name of
 # current module (__name__) as argument.
 app = Flask(__name__)
@@ -20,10 +19,10 @@ app = Flask(__name__)
 # })
 
 kable = configure({
-    "clientId": 'adamsommer',
-    "clientSecret": 'sk_test.JtzSuyWj.Y4poUizC8pWtdfd6uzLmaULowAmHOyGy',
+    "client_id": 'kci_75bfe76dea214218be408fe6fa241f07',
+    "client_secret": 'sk_test.jjrhHXZL.XdSSvBt22dKQdmMvjpiQ9F9v1DGtw26h',
     "environment": 'TEST',
-    "baseUrl": 'https://something.com'
+    "base_url": 'https://something.com'
 })
 
 
